@@ -30,19 +30,18 @@
 #include <QPalette>
 #include <QWidget>
 #include "Common.h"
-#include "DialogSettings.h"
 #include "FilterTextTranslator.h"
 #include "HtmlTranslator.h"
+#include "Settings.h"
 
 namespace GmicQt
 {
 
-BoolParameter::BoolParameter(QObject * parent) : AbstractParameter(parent), _default(false), _value(false), _label(nullptr), _checkBox(nullptr), _connected(false) {}
+BoolParameter::BoolParameter(QObject * parent) : AbstractParameter(parent), _default(false), _value(false), _checkBox(nullptr), _connected(false) {}
 
 BoolParameter::~BoolParameter()
 {
   delete _checkBox;
-  delete _label;
 }
 
 int BoolParameter::size() const
@@ -56,13 +55,12 @@ bool BoolParameter::addTo(QWidget * widget, int row)
   Q_ASSERT_X(_grid, __PRETTY_FUNCTION__, "No grid layout in widget");
   _row = row;
   delete _checkBox;
-  delete _label;
   _checkBox = new QCheckBox(_name, widget);
   _checkBox->setChecked(_value);
-  if (DialogSettings::darkThemeEnabled()) {
+  if (Settings::darkThemeEnabled()) {
     QPalette p = _checkBox->palette();
-    p.setColor(QPalette::Text, DialogSettings::CheckBoxTextColor);
-    p.setColor(QPalette::Base, DialogSettings::CheckBoxBaseColor);
+    p.setColor(QPalette::Text, Settings::CheckBoxTextColor);
+    p.setColor(QPalette::Base, Settings::CheckBoxBaseColor);
     _checkBox->setPalette(p);
   }
   _grid->addWidget(_checkBox, row, 0, 1, 3);
